# Wishlist

This is a list of features that it would be nice to have in this program.

## Recognize the following tags:

- Conditional tags
- AB Test tags

## Validate Course Updates:

- Check that the update file is found (and that json/html aren't clashing)
- Validate the json/html in course updates

## Parsing:

- Check textbook and tab structure in course block validation
- When checking links, check that textbook/tabs links point to somewhere that exists
- Check that python scripts in problems run (and are preferably wrapped in CDATA)
- Check that customresponse graders grade correctly when given expected answer
